@@ -1,5 +1,5 @@
 package Adapter::Async::OrderedList::Array;
-$Adapter::Async::OrderedList::Array::VERSION = '0.012';
+$Adapter::Async::OrderedList::Array::VERSION = '0.013';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Adapter::Async::OrderedList::Array - arrayref adapter
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 DESCRIPTION
 
@@ -115,6 +115,39 @@ sub get {
 	Future->wrap(\@items)
 }
 
+=head2 range
+
+Retrieves all items in a range.
+
+=over 4
+
+=item * start
+
+=item * end
+
+=item * count
+
+=item * on_item
+
+=back
+
+=cut
+
+sub range {
+	my ($self, %args) = @_;
+	my $idx = delete $args{start} || 0;
+	my $code = delete $args{on_item};
+	my $max = $#{$self->{data}};
+	$args{end} //= $idx + $args{count} if exists $args{count};
+	$args{end} //= $max;
+	while($idx < $args{end}) {
+		last if $idx > $max;
+		$code->($idx, $self->{data}[$idx]);
+		++$idx;
+	}
+	Future->done
+}
+
 1;
 
 __END__
